/****************************************************************************
** Meta object code from reading C++ file 'kgrrunner.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kgoldrunner-26.08.0/src/kgrrunner.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgrrunner.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9KGrRunnerE_t {};
} // unnamed namespace

template <> constexpr inline auto KGrRunner::qt_create_metaobjectdata<qt_meta_tag_ZN9KGrRunnerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGrRunner",
        "incScore",
        "",
        "n",
        "startAnimation",
        "spriteId",
        "repeating",
        "i",
        "j",
        "time",
        "Direction",
        "dirn",
        "AnimationType",
        "type"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'incScore'
        QtMocHelpers::SignalData<void(const int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'startAnimation'
        QtMocHelpers::SignalData<void(const int, const bool, const int, const int, const int, const Direction, const AnimationType)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Bool, 6 }, { QMetaType::Int, 7 }, { QMetaType::Int, 8 },
            { QMetaType::Int, 9 }, { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KGrRunner, qt_meta_tag_ZN9KGrRunnerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KGrRunner::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KGrRunnerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KGrRunnerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9KGrRunnerE_t>.metaTypes,
    nullptr
} };

void KGrRunner::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KGrRunner *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->incScore((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->startAnimation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<Direction>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<AnimationType>>(_a[7]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KGrRunner::*)(const int )>(_a, &KGrRunner::incScore, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrRunner::*)(const int , const bool , const int , const int , const int , const Direction , const AnimationType )>(_a, &KGrRunner::startAnimation, 1))
            return;
    }
}

const QMetaObject *KGrRunner::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGrRunner::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KGrRunnerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KGrRunner::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KGrRunner::incScore(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KGrRunner::startAnimation(const int _t1, const bool _t2, const int _t3, const int _t4, const int _t5, const Direction _t6, const AnimationType _t7)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7);
}
namespace {
struct qt_meta_tag_ZN7KGrHeroE_t {};
} // unnamed namespace

template <> constexpr inline auto KGrHero::qt_create_metaobjectdata<qt_meta_tag_ZN7KGrHeroE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGrHero",
        "soundSignal",
        "",
        "n",
        "onOff",
        "invalidDig"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'soundSignal'
        QtMocHelpers::SignalData<void(const int, const bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Bool, 4 },
        }}),
        // Signal 'soundSignal'
        QtMocHelpers::SignalData<void(const int)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'invalidDig'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KGrHero, qt_meta_tag_ZN7KGrHeroE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KGrHero::staticMetaObject = { {
    QMetaObject::SuperData::link<KGrRunner::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KGrHeroE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KGrHeroE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KGrHeroE_t>.metaTypes,
    nullptr
} };

void KGrHero::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KGrHero *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->soundSignal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->soundSignal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->invalidDig(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KGrHero::*)(const int , const bool )>(_a, &KGrHero::soundSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrHero::*)()>(_a, &KGrHero::invalidDig, 2))
            return;
    }
}

const QMetaObject *KGrHero::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGrHero::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KGrHeroE_t>.strings))
        return static_cast<void*>(this);
    return KGrRunner::qt_metacast(_clname);
}

int KGrHero::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KGrRunner::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void KGrHero::soundSignal(const int _t1, const bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 2
void KGrHero::invalidDig()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN8KGrEnemyE_t {};
} // unnamed namespace

template <> constexpr inline auto KGrEnemy::qt_create_metaobjectdata<qt_meta_tag_ZN8KGrEnemyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGrEnemy"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KGrEnemy, qt_meta_tag_ZN8KGrEnemyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KGrEnemy::staticMetaObject = { {
    QMetaObject::SuperData::link<KGrRunner::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KGrEnemyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KGrEnemyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KGrEnemyE_t>.metaTypes,
    nullptr
} };

void KGrEnemy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KGrEnemy *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KGrEnemy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGrEnemy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KGrEnemyE_t>.strings))
        return static_cast<void*>(this);
    return KGrRunner::qt_metacast(_clname);
}

int KGrEnemy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KGrRunner::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
