/****************************************************************************
** Meta object code from reading C++ file 'kgrscene.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kgoldrunner-26.08.0/src/kgrscene.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgrscene.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KGrSceneE_t {};
} // unnamed namespace

template <> constexpr inline auto KGrScene::qt_create_metaobjectdata<qt_meta_tag_ZN8KGrSceneE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGrScene",
        "fadeFinished",
        "",
        "redrawEditToolbar",
        "showLives",
        "lives",
        "showScore",
        "score",
        "makeSprite",
        "type",
        "i",
        "j",
        "animate",
        "missed",
        "gotGold",
        "spriteId",
        "spriteHasGold",
        "lost",
        "showHiddenLadders",
        "QList<int>",
        "ladders",
        "width",
        "deleteSprite",
        "id",
        "deleteAllSprites",
        "paintCell",
        "startAnimation",
        "repeating",
        "time",
        "Direction",
        "dirn",
        "AnimationType",
        "preRenderSprites",
        "setMousePos",
        "getMousePos",
        "int&",
        "drawSpotlight",
        "ratio"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fadeFinished'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'redrawEditToolbar'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showLives'
        QtMocHelpers::SlotData<void(long)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Long, 5 },
        }}),
        // Slot 'showScore'
        QtMocHelpers::SlotData<void(long)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Long, 7 },
        }}),
        // Slot 'makeSprite'
        QtMocHelpers::SlotData<int(const char, int, int)>(8, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Char, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'animate'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'gotGold'
        QtMocHelpers::SlotData<void(const int, const int, const int, const bool, const bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 }, { QMetaType::Bool, 16 },
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'gotGold'
        QtMocHelpers::SlotData<void(const int, const int, const int, const bool)>(14, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 }, { QMetaType::Bool, 16 },
        }}),
        // Slot 'showHiddenLadders'
        QtMocHelpers::SlotData<void(const QList<int> &, const int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::Int, 21 },
        }}),
        // Slot 'deleteSprite'
        QtMocHelpers::SlotData<void(const int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'deleteAllSprites'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'paintCell'
        QtMocHelpers::SlotData<void(const int, const int, const char)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { QMetaType::Int, 11 }, { QMetaType::Char, 9 },
        }}),
        // Slot 'startAnimation'
        QtMocHelpers::SlotData<void(const int, const bool, const int, const int, const int, const Direction, const AnimationType)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::Bool, 27 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
            { QMetaType::Int, 28 }, { 0x80000000 | 29, 30 }, { 0x80000000 | 31, 9 },
        }}),
        // Slot 'preRenderSprites'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setMousePos'
        QtMocHelpers::SlotData<void(const int, const int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'getMousePos'
        QtMocHelpers::SlotData<void(int &, int &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 10 }, { 0x80000000 | 35, 11 },
        }}),
        // Slot 'drawSpotlight'
        QtMocHelpers::SlotData<void(qreal)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 37 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KGrScene, qt_meta_tag_ZN8KGrSceneE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KGrScene::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsScene::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KGrSceneE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KGrSceneE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KGrSceneE_t>.metaTypes,
    nullptr
} };

void KGrScene::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KGrScene *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fadeFinished(); break;
        case 1: _t->redrawEditToolbar(); break;
        case 2: _t->showLives((*reinterpret_cast<std::add_pointer_t<long>>(_a[1]))); break;
        case 3: _t->showScore((*reinterpret_cast<std::add_pointer_t<long>>(_a[1]))); break;
        case 4: { int _r = _t->makeSprite((*reinterpret_cast<std::add_pointer_t<char>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->animate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->gotGold((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 7: _t->gotGold((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 8: _t->showHiddenLadders((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->deleteSprite((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->deleteAllSprites(); break;
        case 11: _t->paintCell((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<char>>(_a[3]))); break;
        case 12: _t->startAnimation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<Direction>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<AnimationType>>(_a[7]))); break;
        case 13: _t->preRenderSprites(); break;
        case 14: _t->setMousePos((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 15: _t->getMousePos((*reinterpret_cast<std::add_pointer_t<int&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int&>>(_a[2]))); break;
        case 16: _t->drawSpotlight((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KGrScene::*)()>(_a, &KGrScene::fadeFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrScene::*)()>(_a, &KGrScene::redrawEditToolbar, 1))
            return;
    }
}

const QMetaObject *KGrScene::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGrScene::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KGrSceneE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsScene::qt_metacast(_clname);
}

int KGrScene::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsScene::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void KGrScene::fadeFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KGrScene::redrawEditToolbar()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
