/****************************************************************************
** Meta object code from reading C++ file 'kgrgame.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kgoldrunner-26.08.0/src/kgrgame.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgrgame.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KGrGameE_t {};
} // unnamed namespace

template <> constexpr inline auto KGrGame::qt_create_metaobjectdata<qt_meta_tag_ZN7KGrGameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGrGame",
        "showScore",
        "",
        "showLives",
        "hintAvailable",
        "setEditMenu",
        "gameFreeze",
        "quitGame",
        "setToggle",
        "actionName",
        "onOff",
        "setAvail",
        "initGame",
        "gameActions",
        "action",
        "editActions",
        "editToolbarActions",
        "settings",
        "kbControl",
        "dirn",
        "pressed",
        "incScore",
        "n",
        "playSound",
        "interruptDemo",
        "endLevel",
        "result",
        "finalBreath",
        "repeatLevel",
        "goUpOneLevel",
        "quickStartPlay",
        "quickStartNewGame",
        "quickStartUseMenu",
        "quickStartQuit",
        "dbgControl",
        "code"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showScore'
        QtMocHelpers::SignalData<void(long)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Long, 2 },
        }}),
        // Signal 'showLives'
        QtMocHelpers::SignalData<void(long)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Long, 2 },
        }}),
        // Signal 'hintAvailable'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'setEditMenu'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'gameFreeze'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'quitGame'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'setToggle'
        QtMocHelpers::SignalData<void(const QString &, const bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::Bool, 10 },
        }}),
        // Signal 'setAvail'
        QtMocHelpers::SignalData<void(const QString &, const bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::Bool, 10 },
        }}),
        // Slot 'initGame'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gameActions'
        QtMocHelpers::SlotData<void(const int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'editActions'
        QtMocHelpers::SlotData<void(const int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'editToolbarActions'
        QtMocHelpers::SlotData<void(const int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'settings'
        QtMocHelpers::SlotData<void(const int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'kbControl'
        QtMocHelpers::SlotData<void(const int, const bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'kbControl'
        QtMocHelpers::SlotData<void(const int)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'incScore'
        QtMocHelpers::SlotData<void(const int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'playSound'
        QtMocHelpers::SlotData<void(const int, const bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 }, { QMetaType::Bool, 10 },
        }}),
        // Slot 'playSound'
        QtMocHelpers::SlotData<void(const int)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'interruptDemo'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'endLevel'
        QtMocHelpers::SlotData<void(const int)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'finalBreath'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'repeatLevel'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goUpOneLevel'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'quickStartPlay'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'quickStartNewGame'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'quickStartUseMenu'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'quickStartQuit'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'dbgControl'
        QtMocHelpers::SlotData<void(const int)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 35 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KGrGame, qt_meta_tag_ZN7KGrGameE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KGrGame::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KGrGameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KGrGameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KGrGameE_t>.metaTypes,
    nullptr
} };

void KGrGame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KGrGame *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showScore((*reinterpret_cast<std::add_pointer_t<long>>(_a[1]))); break;
        case 1: _t->showLives((*reinterpret_cast<std::add_pointer_t<long>>(_a[1]))); break;
        case 2: _t->hintAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->setEditMenu((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->gameFreeze((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->quitGame(); break;
        case 6: _t->setToggle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 7: _t->setAvail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->initGame(); break;
        case 9: _t->gameActions((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->editActions((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->editToolbarActions((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->settings((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->kbControl((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 14: _t->kbControl((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->incScore((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->playSound((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 17: _t->playSound((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->interruptDemo(); break;
        case 19: _t->endLevel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->finalBreath(); break;
        case 21: _t->repeatLevel(); break;
        case 22: _t->goUpOneLevel(); break;
        case 23: _t->quickStartPlay(); break;
        case 24: _t->quickStartNewGame(); break;
        case 25: _t->quickStartUseMenu(); break;
        case 26: _t->quickStartQuit(); break;
        case 27: _t->dbgControl((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KGrGame::*)(long )>(_a, &KGrGame::showScore, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrGame::*)(long )>(_a, &KGrGame::showLives, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrGame::*)(bool )>(_a, &KGrGame::hintAvailable, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrGame::*)(bool )>(_a, &KGrGame::setEditMenu, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrGame::*)(bool )>(_a, &KGrGame::gameFreeze, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrGame::*)()>(_a, &KGrGame::quitGame, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrGame::*)(const QString & , const bool )>(_a, &KGrGame::setToggle, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrGame::*)(const QString & , const bool )>(_a, &KGrGame::setAvail, 7))
            return;
    }
}

const QMetaObject *KGrGame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGrGame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KGrGameE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KGrGame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void KGrGame::showScore(long _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KGrGame::showLives(long _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KGrGame::hintAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KGrGame::setEditMenu(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KGrGame::gameFreeze(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KGrGame::quitGame()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KGrGame::setToggle(const QString & _t1, const bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void KGrGame::setAvail(const QString & _t1, const bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}
QT_WARNING_POP
