/****************************************************************************
** Meta object code from reading C++ file 'kgrlevelplayer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kgoldrunner-26.08.0/src/kgrlevelplayer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgrlevelplayer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14KGrLevelPlayerE_t {};
} // unnamed namespace

template <> constexpr inline auto KGrLevelPlayer::qt_create_metaobjectdata<qt_meta_tag_ZN14KGrLevelPlayerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGrLevelPlayer",
        "endLevel",
        "",
        "result",
        "getMousePos",
        "int&",
        "i",
        "j",
        "setMousePos",
        "animation",
        "missed",
        "paintCell",
        "tileType",
        "makeSprite",
        "spriteType",
        "startAnimation",
        "spriteId",
        "repeating",
        "time",
        "Direction",
        "dirn",
        "AnimationType",
        "type",
        "deleteSprite",
        "gotGold",
        "hasGold",
        "lost",
        "interruptDemo",
        "tick",
        "scaledTime",
        "doDig",
        "button"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'endLevel'
        QtMocHelpers::SignalData<void(const int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'getMousePos'
        QtMocHelpers::SignalData<void(int &, int &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 },
        }}),
        // Signal 'setMousePos'
        QtMocHelpers::SignalData<void(const int, const int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::Int, 7 },
        }}),
        // Signal 'animation'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Signal 'paintCell'
        QtMocHelpers::SignalData<void(int, int, char)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::Int, 7 }, { QMetaType::Char, 12 },
        }}),
        // Signal 'makeSprite'
        QtMocHelpers::SignalData<int(char, int, int)>(13, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Char, 14 }, { QMetaType::Int, 6 }, { QMetaType::Int, 7 },
        }}),
        // Signal 'startAnimation'
        QtMocHelpers::SignalData<void(const int, const bool, const int, const int, const int, const Direction, const AnimationType)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::Bool, 17 }, { QMetaType::Int, 6 }, { QMetaType::Int, 7 },
            { QMetaType::Int, 18 }, { 0x80000000 | 19, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Signal 'deleteSprite'
        QtMocHelpers::SignalData<void(const int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Signal 'gotGold'
        QtMocHelpers::SignalData<void(const int, const int, const int, const bool, const bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::Int, 6 }, { QMetaType::Int, 7 }, { QMetaType::Bool, 25 },
            { QMetaType::Bool, 26 },
        }}),
        // Signal 'interruptDemo'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tick'
        QtMocHelpers::SlotData<void(bool, int)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 10 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'doDig'
        QtMocHelpers::SlotData<void(int)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KGrLevelPlayer, qt_meta_tag_ZN14KGrLevelPlayerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KGrLevelPlayer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KGrLevelPlayerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KGrLevelPlayerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14KGrLevelPlayerE_t>.metaTypes,
    nullptr
} };

void KGrLevelPlayer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KGrLevelPlayer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->endLevel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->getMousePos((*reinterpret_cast<std::add_pointer_t<int&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int&>>(_a[2]))); break;
        case 2: _t->setMousePos((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->animation((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->paintCell((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<char>>(_a[3]))); break;
        case 5: { int _r = _t->makeSprite((*reinterpret_cast<std::add_pointer_t<char>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->startAnimation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<Direction>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<AnimationType>>(_a[7]))); break;
        case 7: _t->deleteSprite((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->gotGold((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 9: _t->interruptDemo(); break;
        case 10: _t->tick((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 11: _t->doDig((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KGrLevelPlayer::*)(const int )>(_a, &KGrLevelPlayer::endLevel, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrLevelPlayer::*)(int & , int & )>(_a, &KGrLevelPlayer::getMousePos, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrLevelPlayer::*)(const int , const int )>(_a, &KGrLevelPlayer::setMousePos, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrLevelPlayer::*)(bool )>(_a, &KGrLevelPlayer::animation, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrLevelPlayer::*)(int , int , char )>(_a, &KGrLevelPlayer::paintCell, 4))
            return;
        if (QtMocHelpers::indexOfMethod<int (KGrLevelPlayer::*)(char , int , int )>(_a, &KGrLevelPlayer::makeSprite, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrLevelPlayer::*)(const int , const bool , const int , const int , const int , const Direction , const AnimationType )>(_a, &KGrLevelPlayer::startAnimation, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrLevelPlayer::*)(const int )>(_a, &KGrLevelPlayer::deleteSprite, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrLevelPlayer::*)(const int , const int , const int , const bool , const bool )>(_a, &KGrLevelPlayer::gotGold, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KGrLevelPlayer::*)()>(_a, &KGrLevelPlayer::interruptDemo, 9))
            return;
    }
}

const QMetaObject *KGrLevelPlayer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGrLevelPlayer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KGrLevelPlayerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KGrLevelPlayer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void KGrLevelPlayer::endLevel(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KGrLevelPlayer::getMousePos(int & _t1, int & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KGrLevelPlayer::setMousePos(const int _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KGrLevelPlayer::animation(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KGrLevelPlayer::paintCell(int _t1, int _t2, char _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
int KGrLevelPlayer::makeSprite(char _t1, int _t2, int _t3)
{
    int _t0{};
    QMetaObject::activate<int>(this, &staticMetaObject, 5, std::addressof(_t0), _t1, _t2, _t3);
    return _t0;
}

// SIGNAL 6
void KGrLevelPlayer::startAnimation(const int _t1, const bool _t2, const int _t3, const int _t4, const int _t5, const Direction _t6, const AnimationType _t7)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7);
}

// SIGNAL 7
void KGrLevelPlayer::deleteSprite(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KGrLevelPlayer::gotGold(const int _t1, const int _t2, const int _t3, const bool _t4, const bool _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 9
void KGrLevelPlayer::interruptDemo()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
