/****************************************************************************
** Meta object code from reading C++ file 'kgrthemetypes.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kgoldrunner-26.08.0/src/kgrthemetypes.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgrthemetypes.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14KGrActorsThemeE_t {};
} // unnamed namespace

template <> constexpr inline auto KGrActorsTheme::qt_create_metaobjectdata<qt_meta_tag_ZN14KGrActorsThemeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGrActorsTheme",
        "",
        "identifier",
        "parent"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    using Constructor = QtMocHelpers::NoType;
    QtMocHelpers::UintData qt_constructors {
        QtMocHelpers::ConstructorData<Constructor(const QByteArray &, QObject *)>(1, QMC::AccessPublic, {{
            { QMetaType::QByteArray, 2 }, { QMetaType::QObjectStar, 3 },
        }}),
        QtMocHelpers::ConstructorData<Constructor(const QByteArray &)>(1, QMC::AccessPublic | QMC::MethodCloned, {{
            { QMetaType::QByteArray, 2 },
        }}),
    };
    return QtMocHelpers::metaObjectData<KGrActorsTheme, qt_meta_tag_ZN14KGrActorsThemeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors);
}
Q_CONSTINIT const QMetaObject KGrActorsTheme::staticMetaObject = { {
    QMetaObject::SuperData::link<KGameTheme::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KGrActorsThemeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KGrActorsThemeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14KGrActorsThemeE_t>.metaTypes,
    nullptr
} };

void KGrActorsTheme::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KGrActorsTheme *>(_o);
    if (_c == QMetaObject::CreateInstance) {
        switch (_id) {
        case 0: { KGrActorsTheme *_r = new KGrActorsTheme((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        case 1: { KGrActorsTheme *_r = new KGrActorsTheme((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        default: break;
        }
    }
    if (_c == QMetaObject::ConstructInPlace) {
        switch (_id) {
        case 0: { new (_a[0]) KGrActorsTheme((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2]))); } break;
        case 1: { new (_a[0]) KGrActorsTheme((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); } break;
        default: break;
        }
    }
    (void)_t;
}

const QMetaObject *KGrActorsTheme::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGrActorsTheme::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KGrActorsThemeE_t>.strings))
        return static_cast<void*>(this);
    return KGameTheme::qt_metacast(_clname);
}

int KGrActorsTheme::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KGameTheme::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN11KGrSetThemeE_t {};
} // unnamed namespace

template <> constexpr inline auto KGrSetTheme::qt_create_metaobjectdata<qt_meta_tag_ZN11KGrSetThemeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KGrSetTheme",
        "",
        "identifier",
        "parent"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    using Constructor = QtMocHelpers::NoType;
    QtMocHelpers::UintData qt_constructors {
        QtMocHelpers::ConstructorData<Constructor(const QByteArray &, QObject *)>(1, QMC::AccessPublic, {{
            { QMetaType::QByteArray, 2 }, { QMetaType::QObjectStar, 3 },
        }}),
        QtMocHelpers::ConstructorData<Constructor(const QByteArray &)>(1, QMC::AccessPublic | QMC::MethodCloned, {{
            { QMetaType::QByteArray, 2 },
        }}),
    };
    return QtMocHelpers::metaObjectData<KGrSetTheme, qt_meta_tag_ZN11KGrSetThemeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors);
}
Q_CONSTINIT const QMetaObject KGrSetTheme::staticMetaObject = { {
    QMetaObject::SuperData::link<KGameTheme::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KGrSetThemeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KGrSetThemeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11KGrSetThemeE_t>.metaTypes,
    nullptr
} };

void KGrSetTheme::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KGrSetTheme *>(_o);
    if (_c == QMetaObject::CreateInstance) {
        switch (_id) {
        case 0: { KGrSetTheme *_r = new KGrSetTheme((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        case 1: { KGrSetTheme *_r = new KGrSetTheme((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        default: break;
        }
    }
    if (_c == QMetaObject::ConstructInPlace) {
        switch (_id) {
        case 0: { new (_a[0]) KGrSetTheme((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2]))); } break;
        case 1: { new (_a[0]) KGrSetTheme((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); } break;
        default: break;
        }
    }
    (void)_t;
}

const QMetaObject *KGrSetTheme::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGrSetTheme::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KGrSetThemeE_t>.strings))
        return static_cast<void*>(this);
    return KGameTheme::qt_metacast(_clname);
}

int KGrSetTheme::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KGameTheme::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
